"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from jsonpath import JSONPath
from mesa_sdk import errors, models, utils
from mesa_sdk._hooks import HookContext
from mesa_sdk.types import OptionalNullable, UNSET
from mesa_sdk.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Awaitable, Dict, List, Mapping, Optional, Union


class Repos(BaseSDK):
    def create(
        self,
        *,
        org: str,
        name: str,
        default_branch: Optional[str] = "main",
        upstream: Optional[
            Union[
                models.PostByOrgReposUpstreamRequest,
                models.PostByOrgReposUpstreamRequestTypedDict,
            ]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PostByOrgReposResponse:
        r"""Create repository

        Create a new repository in the organization

        :param org:
        :param name:
        :param default_branch:
        :param upstream:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostByOrgReposRequest(
            org=org,
            body=models.PostByOrgReposRequestBody(
                name=name,
                default_branch=default_branch,
                upstream=utils.get_pydantic_model(
                    upstream, Optional[models.PostByOrgReposUpstreamRequest]
                ),
            ),
        )

        req = self._build_request(
            method="POST",
            path="/{org}/repos",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                True,
                "json",
                Optional[models.PostByOrgReposRequestBody],
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="postByOrgRepos",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return unmarshal_json_response(models.PostByOrgReposResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgReposBadRequestErrorData, http_res
            )
            raise errors.PostByOrgReposBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgReposUnauthorizedErrorData, http_res
            )
            raise errors.PostByOrgReposUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgReposForbiddenErrorData, http_res
            )
            raise errors.PostByOrgReposForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgReposNotFoundErrorData, http_res
            )
            raise errors.PostByOrgReposNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgReposNotAcceptableErrorData, http_res
            )
            raise errors.PostByOrgReposNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgReposConflictErrorData, http_res
            )
            raise errors.PostByOrgReposConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgReposInternalServerErrorData, http_res
            )
            raise errors.PostByOrgReposInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def create_async(
        self,
        *,
        org: str,
        name: str,
        default_branch: Optional[str] = "main",
        upstream: Optional[
            Union[
                models.PostByOrgReposUpstreamRequest,
                models.PostByOrgReposUpstreamRequestTypedDict,
            ]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PostByOrgReposResponse:
        r"""Create repository

        Create a new repository in the organization

        :param org:
        :param name:
        :param default_branch:
        :param upstream:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostByOrgReposRequest(
            org=org,
            body=models.PostByOrgReposRequestBody(
                name=name,
                default_branch=default_branch,
                upstream=utils.get_pydantic_model(
                    upstream, Optional[models.PostByOrgReposUpstreamRequest]
                ),
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/{org}/repos",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                True,
                "json",
                Optional[models.PostByOrgReposRequestBody],
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="postByOrgRepos",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "201", "application/json"):
            return unmarshal_json_response(models.PostByOrgReposResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgReposBadRequestErrorData, http_res
            )
            raise errors.PostByOrgReposBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgReposUnauthorizedErrorData, http_res
            )
            raise errors.PostByOrgReposUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgReposForbiddenErrorData, http_res
            )
            raise errors.PostByOrgReposForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgReposNotFoundErrorData, http_res
            )
            raise errors.PostByOrgReposNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgReposNotAcceptableErrorData, http_res
            )
            raise errors.PostByOrgReposNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgReposConflictErrorData, http_res
            )
            raise errors.PostByOrgReposConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgReposInternalServerErrorData, http_res
            )
            raise errors.PostByOrgReposInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    def list(
        self,
        *,
        org: str,
        cursor: Optional[str] = None,
        limit: Optional[int] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Optional[models.GetByOrgReposResponse]:
        r"""List repositories

        List all repositories in the organization

        :param org:
        :param cursor:
        :param limit:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetByOrgReposRequest(
            org=org,
            cursor=cursor,
            limit=limit,
        )

        req = self._build_request(
            method="GET",
            path="/{org}/repos",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getByOrgRepos",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        def next_func() -> Optional[models.GetByOrgReposResponse]:
            body = utils.unmarshal_json(http_res.text, Union[Dict[Any, Any], List[Any]])

            next_cursor = JSONPath("$.next_cursor").parse(body)

            if len(next_cursor) == 0:
                return None

            next_cursor = next_cursor[0]
            if next_cursor is None or str(next_cursor).strip() == "":
                return None
            results = JSONPath("$.repos").parse(body)
            if len(results) == 0 or len(results[0]) == 0:
                return None

            return self.list(
                org=org,
                cursor=next_cursor,
                limit=limit,
                retries=retries,
            )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.GetByOrgReposResponse(
                result=unmarshal_json_response(
                    models.GetByOrgReposResponseBody, http_res
                ),
                next=next_func,
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgReposBadRequestErrorData, http_res
            )
            raise errors.GetByOrgReposBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgReposUnauthorizedErrorData, http_res
            )
            raise errors.GetByOrgReposUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgReposForbiddenErrorData, http_res
            )
            raise errors.GetByOrgReposForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgReposNotFoundErrorData, http_res
            )
            raise errors.GetByOrgReposNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgReposNotAcceptableErrorData, http_res
            )
            raise errors.GetByOrgReposNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgReposConflictErrorData, http_res
            )
            raise errors.GetByOrgReposConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgReposInternalServerErrorData, http_res
            )
            raise errors.GetByOrgReposInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def list_async(
        self,
        *,
        org: str,
        cursor: Optional[str] = None,
        limit: Optional[int] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Optional[models.GetByOrgReposResponse]:
        r"""List repositories

        List all repositories in the organization

        :param org:
        :param cursor:
        :param limit:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetByOrgReposRequest(
            org=org,
            cursor=cursor,
            limit=limit,
        )

        req = self._build_request_async(
            method="GET",
            path="/{org}/repos",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getByOrgRepos",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        def next_func() -> Awaitable[Optional[models.GetByOrgReposResponse]]:
            body = utils.unmarshal_json(http_res.text, Union[Dict[Any, Any], List[Any]])

            async def empty_result():
                return None

            next_cursor = JSONPath("$.next_cursor").parse(body)

            if len(next_cursor) == 0:
                return empty_result()

            next_cursor = next_cursor[0]
            if next_cursor is None or str(next_cursor).strip() == "":
                return empty_result()
            results = JSONPath("$.repos").parse(body)
            if len(results) == 0 or len(results[0]) == 0:
                return empty_result()

            return self.list_async(
                org=org,
                cursor=next_cursor,
                limit=limit,
                retries=retries,
            )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.GetByOrgReposResponse(
                result=unmarshal_json_response(
                    models.GetByOrgReposResponseBody, http_res
                ),
                next=next_func,
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgReposBadRequestErrorData, http_res
            )
            raise errors.GetByOrgReposBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgReposUnauthorizedErrorData, http_res
            )
            raise errors.GetByOrgReposUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgReposForbiddenErrorData, http_res
            )
            raise errors.GetByOrgReposForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgReposNotFoundErrorData, http_res
            )
            raise errors.GetByOrgReposNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgReposNotAcceptableErrorData, http_res
            )
            raise errors.GetByOrgReposNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgReposConflictErrorData, http_res
            )
            raise errors.GetByOrgReposConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgReposInternalServerErrorData, http_res
            )
            raise errors.GetByOrgReposInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    def get(
        self,
        *,
        org: str,
        repo: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetByOrgByRepoResponse:
        r"""Get repository

        Get metadata for a specific repository

        :param org:
        :param repo:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetByOrgByRepoRequest(
            org=org,
            repo=repo,
        )

        req = self._build_request(
            method="GET",
            path="/{org}/{repo}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getByOrgByRepo",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.GetByOrgByRepoResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoBadRequestErrorData, http_res
            )
            raise errors.GetByOrgByRepoBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoUnauthorizedErrorData, http_res
            )
            raise errors.GetByOrgByRepoUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoForbiddenErrorData, http_res
            )
            raise errors.GetByOrgByRepoForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoNotFoundErrorData, http_res
            )
            raise errors.GetByOrgByRepoNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoNotAcceptableErrorData, http_res
            )
            raise errors.GetByOrgByRepoNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoConflictErrorData, http_res
            )
            raise errors.GetByOrgByRepoConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoInternalServerErrorData, http_res
            )
            raise errors.GetByOrgByRepoInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def get_async(
        self,
        *,
        org: str,
        repo: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetByOrgByRepoResponse:
        r"""Get repository

        Get metadata for a specific repository

        :param org:
        :param repo:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetByOrgByRepoRequest(
            org=org,
            repo=repo,
        )

        req = self._build_request_async(
            method="GET",
            path="/{org}/{repo}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getByOrgByRepo",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.GetByOrgByRepoResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoBadRequestErrorData, http_res
            )
            raise errors.GetByOrgByRepoBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoUnauthorizedErrorData, http_res
            )
            raise errors.GetByOrgByRepoUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoForbiddenErrorData, http_res
            )
            raise errors.GetByOrgByRepoForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoNotFoundErrorData, http_res
            )
            raise errors.GetByOrgByRepoNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoNotAcceptableErrorData, http_res
            )
            raise errors.GetByOrgByRepoNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoConflictErrorData, http_res
            )
            raise errors.GetByOrgByRepoConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoInternalServerErrorData, http_res
            )
            raise errors.GetByOrgByRepoInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    def delete(
        self,
        *,
        org: str,
        repo: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DeleteByOrgByRepoResponse:
        r"""Delete repository

        Permanently delete a repository and all its data

        :param org:
        :param repo:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteByOrgByRepoRequest(
            org=org,
            repo=repo,
        )

        req = self._build_request(
            method="DELETE",
            path="/{org}/{repo}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="deleteByOrgByRepo",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.DeleteByOrgByRepoResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoBadRequestErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoUnauthorizedErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoForbiddenErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoNotFoundErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoNotAcceptableErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoConflictErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoInternalServerErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def delete_async(
        self,
        *,
        org: str,
        repo: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.DeleteByOrgByRepoResponse:
        r"""Delete repository

        Permanently delete a repository and all its data

        :param org:
        :param repo:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteByOrgByRepoRequest(
            org=org,
            repo=repo,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/{org}/{repo}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="deleteByOrgByRepo",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.DeleteByOrgByRepoResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoBadRequestErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoUnauthorizedErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoForbiddenErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoNotFoundErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoNotAcceptableErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoConflictErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.DeleteByOrgByRepoInternalServerErrorData, http_res
            )
            raise errors.DeleteByOrgByRepoInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    def update(
        self,
        *,
        org: str,
        repo: str,
        name: Optional[str] = None,
        upstream: OptionalNullable[
            Union[
                models.PatchByOrgByRepoUpstreamRequest,
                models.PatchByOrgByRepoUpstreamRequestTypedDict,
            ]
        ] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PatchByOrgByRepoResponse:
        r"""Update repository

        Update repository name or upstream configuration

        :param org:
        :param repo:
        :param name:
        :param upstream:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PatchByOrgByRepoRequest(
            org=org,
            repo=repo,
            body=models.PatchByOrgByRepoRequestBody(
                name=name,
                upstream=utils.get_pydantic_model(
                    upstream, OptionalNullable[models.PatchByOrgByRepoUpstreamRequest]
                ),
            ),
        )

        req = self._build_request(
            method="PATCH",
            path="/{org}/{repo}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                True,
                "json",
                Optional[models.PatchByOrgByRepoRequestBody],
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="patchByOrgByRepo",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PatchByOrgByRepoResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.PatchByOrgByRepoBadRequestErrorData, http_res
            )
            raise errors.PatchByOrgByRepoBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.PatchByOrgByRepoUnauthorizedErrorData, http_res
            )
            raise errors.PatchByOrgByRepoUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.PatchByOrgByRepoForbiddenErrorData, http_res
            )
            raise errors.PatchByOrgByRepoForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.PatchByOrgByRepoNotFoundErrorData, http_res
            )
            raise errors.PatchByOrgByRepoNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.PatchByOrgByRepoNotAcceptableErrorData, http_res
            )
            raise errors.PatchByOrgByRepoNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.PatchByOrgByRepoConflictErrorData, http_res
            )
            raise errors.PatchByOrgByRepoConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.PatchByOrgByRepoInternalServerErrorData, http_res
            )
            raise errors.PatchByOrgByRepoInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def update_async(
        self,
        *,
        org: str,
        repo: str,
        name: Optional[str] = None,
        upstream: OptionalNullable[
            Union[
                models.PatchByOrgByRepoUpstreamRequest,
                models.PatchByOrgByRepoUpstreamRequestTypedDict,
            ]
        ] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PatchByOrgByRepoResponse:
        r"""Update repository

        Update repository name or upstream configuration

        :param org:
        :param repo:
        :param name:
        :param upstream:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PatchByOrgByRepoRequest(
            org=org,
            repo=repo,
            body=models.PatchByOrgByRepoRequestBody(
                name=name,
                upstream=utils.get_pydantic_model(
                    upstream, OptionalNullable[models.PatchByOrgByRepoUpstreamRequest]
                ),
            ),
        )

        req = self._build_request_async(
            method="PATCH",
            path="/{org}/{repo}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                True,
                "json",
                Optional[models.PatchByOrgByRepoRequestBody],
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="patchByOrgByRepo",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PatchByOrgByRepoResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.PatchByOrgByRepoBadRequestErrorData, http_res
            )
            raise errors.PatchByOrgByRepoBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.PatchByOrgByRepoUnauthorizedErrorData, http_res
            )
            raise errors.PatchByOrgByRepoUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.PatchByOrgByRepoForbiddenErrorData, http_res
            )
            raise errors.PatchByOrgByRepoForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.PatchByOrgByRepoNotFoundErrorData, http_res
            )
            raise errors.PatchByOrgByRepoNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.PatchByOrgByRepoNotAcceptableErrorData, http_res
            )
            raise errors.PatchByOrgByRepoNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.PatchByOrgByRepoConflictErrorData, http_res
            )
            raise errors.PatchByOrgByRepoConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.PatchByOrgByRepoInternalServerErrorData, http_res
            )
            raise errors.PatchByOrgByRepoInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    def get_sync_status(
        self,
        *,
        org: str,
        repo: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetByOrgByRepoSyncResponse:
        r"""Get sync status

        Get the sync status for a repository with upstream configured

        :param org:
        :param repo:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetByOrgByRepoSyncRequest(
            org=org,
            repo=repo,
        )

        req = self._build_request(
            method="GET",
            path="/{org}/{repo}/sync",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getByOrgByRepoSync",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.GetByOrgByRepoSyncResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoSyncBadRequestErrorData, http_res
            )
            raise errors.GetByOrgByRepoSyncBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoSyncUnauthorizedErrorData, http_res
            )
            raise errors.GetByOrgByRepoSyncUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoSyncForbiddenErrorData, http_res
            )
            raise errors.GetByOrgByRepoSyncForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoSyncNotFoundErrorData, http_res
            )
            raise errors.GetByOrgByRepoSyncNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoSyncNotAcceptableErrorData, http_res
            )
            raise errors.GetByOrgByRepoSyncNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoSyncConflictErrorData, http_res
            )
            raise errors.GetByOrgByRepoSyncConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoSyncInternalServerErrorData, http_res
            )
            raise errors.GetByOrgByRepoSyncInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def get_sync_status_async(
        self,
        *,
        org: str,
        repo: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetByOrgByRepoSyncResponse:
        r"""Get sync status

        Get the sync status for a repository with upstream configured

        :param org:
        :param repo:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetByOrgByRepoSyncRequest(
            org=org,
            repo=repo,
        )

        req = self._build_request_async(
            method="GET",
            path="/{org}/{repo}/sync",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getByOrgByRepoSync",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.GetByOrgByRepoSyncResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoSyncBadRequestErrorData, http_res
            )
            raise errors.GetByOrgByRepoSyncBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoSyncUnauthorizedErrorData, http_res
            )
            raise errors.GetByOrgByRepoSyncUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoSyncForbiddenErrorData, http_res
            )
            raise errors.GetByOrgByRepoSyncForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoSyncNotFoundErrorData, http_res
            )
            raise errors.GetByOrgByRepoSyncNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoSyncNotAcceptableErrorData, http_res
            )
            raise errors.GetByOrgByRepoSyncNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoSyncConflictErrorData, http_res
            )
            raise errors.GetByOrgByRepoSyncConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.GetByOrgByRepoSyncInternalServerErrorData, http_res
            )
            raise errors.GetByOrgByRepoSyncInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    def sync(
        self,
        *,
        org: str,
        repo: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PostByOrgByRepoSyncResponse:
        r"""Sync repository

        Trigger a sync from the upstream repository. Waits for sync to complete.

        :param org:
        :param repo:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostByOrgByRepoSyncRequest(
            org=org,
            repo=repo,
        )

        req = self._build_request(
            method="POST",
            path="/{org}/{repo}/sync",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="postByOrgByRepoSync",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PostByOrgByRepoSyncResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoSyncBadRequestErrorData, http_res
            )
            raise errors.PostByOrgByRepoSyncBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoSyncUnauthorizedErrorData, http_res
            )
            raise errors.PostByOrgByRepoSyncUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoSyncForbiddenErrorData, http_res
            )
            raise errors.PostByOrgByRepoSyncForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoSyncNotFoundErrorData, http_res
            )
            raise errors.PostByOrgByRepoSyncNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoSyncNotAcceptableErrorData, http_res
            )
            raise errors.PostByOrgByRepoSyncNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoSyncConflictErrorData, http_res
            )
            raise errors.PostByOrgByRepoSyncConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoSyncInternalServerErrorData, http_res
            )
            raise errors.PostByOrgByRepoSyncInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)

    async def sync_async(
        self,
        *,
        org: str,
        repo: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PostByOrgByRepoSyncResponse:
        r"""Sync repository

        Trigger a sync from the upstream repository. Waits for sync to complete.

        :param org:
        :param repo:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PostByOrgByRepoSyncRequest(
            org=org,
            repo=repo,
        )

        req = self._build_request_async(
            method="POST",
            path="/{org}/{repo}/sync",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="postByOrgByRepoSync",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "406",
                "409",
                "4XX",
                "500",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PostByOrgByRepoSyncResponse, http_res)
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoSyncBadRequestErrorData, http_res
            )
            raise errors.PostByOrgByRepoSyncBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoSyncUnauthorizedErrorData, http_res
            )
            raise errors.PostByOrgByRepoSyncUnauthorizedError(response_data, http_res)
        if utils.match_response(http_res, "403", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoSyncForbiddenErrorData, http_res
            )
            raise errors.PostByOrgByRepoSyncForbiddenError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoSyncNotFoundErrorData, http_res
            )
            raise errors.PostByOrgByRepoSyncNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "406", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoSyncNotAcceptableErrorData, http_res
            )
            raise errors.PostByOrgByRepoSyncNotAcceptableError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoSyncConflictErrorData, http_res
            )
            raise errors.PostByOrgByRepoSyncConflictError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.PostByOrgByRepoSyncInternalServerErrorData, http_res
            )
            raise errors.PostByOrgByRepoSyncInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.MesaDefaultError("API error occurred", http_res, http_res_text)

        raise errors.MesaDefaultError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mesa_sdk.types import BaseModel, Nullable, UNSET_SENTINEL, UnrecognizedStr
from mesa_sdk.utils import (
    FieldMetadata,
    PathParamMetadata,
    QueryParamMetadata,
    validate_const,
)
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


Period = Literal[
    "24h",
    "1w",
    "1m",
    "all",
]


class GetByOrgByRepoAnalyticsRequestTypedDict(TypedDict):
    org: str
    repo: str
    period: NotRequired[Period]


class GetByOrgByRepoAnalyticsRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    repo: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    period: Annotated[
        Optional[Period],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = "all"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["period"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoAnalyticsInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoAnalyticsInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoAnalyticsConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoAnalyticsConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoAnalyticsNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoAnalyticsNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoAnalyticsNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoAnalyticsNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoAnalyticsForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoAnalyticsForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoAnalyticsUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoAnalyticsUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoAnalyticsBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoAnalyticsBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoAnalyticsSummaryTypedDict(TypedDict):
    total_lines: float
    ai_lines: float
    human_lines: float
    providers: Dict[str, float]
    models: Dict[str, float]
    updated: str


class GetByOrgByRepoAnalyticsSummary(BaseModel):
    total_lines: Annotated[float, pydantic.Field(alias="totalLines")]

    ai_lines: Annotated[float, pydantic.Field(alias="aiLines")]

    human_lines: Annotated[float, pydantic.Field(alias="humanLines")]

    providers: Dict[str, float]

    models: Dict[str, float]

    updated: str


class GetByOrgByRepoAnalyticsContributorsTypedDict(TypedDict):
    total_lines: float
    ai_lines: float
    providers: Dict[str, float]
    models: Dict[str, float]
    commit_count: float


class GetByOrgByRepoAnalyticsContributors(BaseModel):
    total_lines: Annotated[float, pydantic.Field(alias="totalLines")]

    ai_lines: Annotated[float, pydantic.Field(alias="aiLines")]

    providers: Dict[str, float]

    models: Dict[str, float]

    commit_count: Annotated[float, pydantic.Field(alias="commitCount")]


class GetByOrgByRepoAnalyticsHistoryTypedDict(TypedDict):
    date_: str
    sha: str
    author: str
    added: float
    removed: float
    ai_lines: float
    message: NotRequired[str]
    providers: NotRequired[Dict[str, float]]
    models: NotRequired[Dict[str, float]]


class GetByOrgByRepoAnalyticsHistory(BaseModel):
    date_: Annotated[str, pydantic.Field(alias="date")]

    sha: str

    author: str

    added: float

    removed: float

    ai_lines: Annotated[float, pydantic.Field(alias="aiLines")]

    message: Optional[str] = None

    providers: Optional[Dict[str, float]] = None

    models: Optional[Dict[str, float]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["message", "providers", "models"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoAnalyticsMetaTypedDict(TypedDict):
    last_attempt: str
    last_success: Nullable[str]
    last_error: Nullable[str]


class GetByOrgByRepoAnalyticsMeta(BaseModel):
    last_attempt: Annotated[str, pydantic.Field(alias="lastAttempt")]

    last_success: Annotated[Nullable[str], pydantic.Field(alias="lastSuccess")]

    last_error: Annotated[Nullable[str], pydantic.Field(alias="lastError")]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetByOrgByRepoAnalyticsAnalyticsTypedDict(TypedDict):
    summary: GetByOrgByRepoAnalyticsSummaryTypedDict
    contributors: Dict[str, GetByOrgByRepoAnalyticsContributorsTypedDict]
    history: List[GetByOrgByRepoAnalyticsHistoryTypedDict]
    version: float
    meta: NotRequired[GetByOrgByRepoAnalyticsMetaTypedDict]


class GetByOrgByRepoAnalyticsAnalytics(BaseModel):
    summary: GetByOrgByRepoAnalyticsSummary

    contributors: Dict[str, GetByOrgByRepoAnalyticsContributors]

    history: List[GetByOrgByRepoAnalyticsHistory]

    version: Annotated[
        Annotated[float, AfterValidator(validate_const(2))],
        pydantic.Field(alias="version"),
    ] = 2

    meta: Annotated[
        Optional[GetByOrgByRepoAnalyticsMeta], pydantic.Field(alias="_meta")
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["_meta"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


GetByOrgByRepoAnalyticsStatus = Union[
    Literal[
        "current",
        "stale",
        "none",
    ],
    UnrecognizedStr,
]


class GetByOrgByRepoAnalyticsResponseTypedDict(TypedDict):
    r"""Analytics data"""

    analytics: Nullable[GetByOrgByRepoAnalyticsAnalyticsTypedDict]
    status: GetByOrgByRepoAnalyticsStatus


class GetByOrgByRepoAnalyticsResponse(BaseModel):
    r"""Analytics data"""

    analytics: Nullable[GetByOrgByRepoAnalyticsAnalytics]

    status: GetByOrgByRepoAnalyticsStatus

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mesa_sdk.types import BaseModel, UNSET_SENTINEL
from mesa_sdk.utils import (
    FieldMetadata,
    PathParamMetadata,
    RequestMetadata,
    validate_const,
)
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class PostByOrgByRepoCommitsAuthorTypedDict(TypedDict):
    name: str
    email: str
    date_: NotRequired[str]


class PostByOrgByRepoCommitsAuthor(BaseModel):
    name: str

    email: str

    date_: Annotated[Optional[str], pydantic.Field(alias="date")] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["date"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class FileDeleteTypedDict(TypedDict):
    path: str
    action: Literal["delete"]


class FileDelete(BaseModel):
    path: str

    action: Annotated[
        Annotated[Literal["delete"], AfterValidator(validate_const("delete"))],
        pydantic.Field(alias="action"),
    ] = "delete"


Encoding = Literal[
    "utf-8",
    "base64",
]


class FileUpsertTypedDict(TypedDict):
    path: str
    content: str
    encoding: NotRequired[Encoding]
    action: Literal["upsert"]


class FileUpsert(BaseModel):
    path: str

    content: str

    encoding: Optional[Encoding] = "utf-8"

    action: Annotated[
        Annotated[
            Optional[Literal["upsert"]], AfterValidator(validate_const("upsert"))
        ],
        pydantic.Field(alias="action"),
    ] = "upsert"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["encoding", "action"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


FileTypedDict = TypeAliasType(
    "FileTypedDict", Union[FileDeleteTypedDict, FileUpsertTypedDict]
)


File = TypeAliasType("File", Union[FileDelete, FileUpsert])


class PostByOrgByRepoCommitsRequestBodyTypedDict(TypedDict):
    branch: str
    message: str
    author: PostByOrgByRepoCommitsAuthorTypedDict
    files: List[FileTypedDict]
    base_sha: NotRequired[str]


class PostByOrgByRepoCommitsRequestBody(BaseModel):
    branch: str

    message: str

    author: PostByOrgByRepoCommitsAuthor

    files: List[File]

    base_sha: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["base_sha"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoCommitsRequestTypedDict(TypedDict):
    org: str
    repo: str
    body: NotRequired[PostByOrgByRepoCommitsRequestBodyTypedDict]


class PostByOrgByRepoCommitsRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    repo: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    body: Annotated[
        Optional[PostByOrgByRepoCommitsRequestBody],
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["body"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoCommitsInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoCommitsInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoCommitsConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoCommitsConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoCommitsNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoCommitsNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoCommitsNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoCommitsNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoCommitsForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoCommitsForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoCommitsUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoCommitsUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoCommitsBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoCommitsBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoCommitsResponseTypedDict(TypedDict):
    r"""Commit created"""

    sha: str
    branch: str
    message: str


class PostByOrgByRepoCommitsResponse(BaseModel):
    r"""Commit created"""

    sha: str

    branch: str

    message: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import getbyorgbyrepoop as models_getbyorgbyrepoop
from mesa_sdk.types import BaseModel
from typing import Optional


class GetByOrgByRepoInternalServerErrorData(BaseModel):
    error: models_getbyorgbyrepoop.GetByOrgByRepoInternalServerErrorError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoInternalServerError(MesaError):
    r"""Internal error"""

    data: GetByOrgByRepoInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoConflictErrorData(BaseModel):
    error: models_getbyorgbyrepoop.GetByOrgByRepoConflictError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoConflictError(MesaError):
    r"""Conflict"""

    data: GetByOrgByRepoConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoNotAcceptableErrorData(BaseModel):
    error: models_getbyorgbyrepoop.GetByOrgByRepoNotAcceptableError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: GetByOrgByRepoNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoNotFoundErrorData(BaseModel):
    error: models_getbyorgbyrepoop.GetByOrgByRepoNotFoundError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoNotFoundError(MesaError):
    r"""Not found"""

    data: GetByOrgByRepoNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoForbiddenErrorData(BaseModel):
    error: models_getbyorgbyrepoop.GetByOrgByRepoForbiddenError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoForbiddenError(MesaError):
    r"""Forbidden"""

    data: GetByOrgByRepoForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoUnauthorizedErrorData(BaseModel):
    error: models_getbyorgbyrepoop.GetByOrgByRepoUnauthorizedError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: GetByOrgByRepoUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoBadRequestErrorData(BaseModel):
    error: models_getbyorgbyrepoop.GetByOrgByRepoBadRequestError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoBadRequestError(MesaError):
    r"""Invalid request"""

    data: GetByOrgByRepoBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from mesa_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from mesa_sdk.utils import FieldMetadata, PathParamMetadata
from pydantic import model_serializer
from typing import Any, Dict, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetByOrgRequestTypedDict(TypedDict):
    org: str


class GetByOrgRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class GetByOrgInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgResponseTypedDict(TypedDict):
    r"""Organization summary"""

    created_at: datetime
    last_commit_at: Nullable[datetime]
    num_repos: int


class GetByOrgResponse(BaseModel):
    r"""Organization summary"""

    created_at: datetime

    last_commit_at: Nullable[datetime]

    num_repos: int

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import deletebyorgbyrepoop as models_deletebyorgbyrepoop
from mesa_sdk.types import BaseModel
from typing import Optional


class DeleteByOrgByRepoInternalServerErrorData(BaseModel):
    error: models_deletebyorgbyrepoop.DeleteByOrgByRepoInternalServerErrorError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoInternalServerError(MesaError):
    r"""Internal error"""

    data: DeleteByOrgByRepoInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoConflictErrorData(BaseModel):
    error: models_deletebyorgbyrepoop.DeleteByOrgByRepoConflictError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoConflictError(MesaError):
    r"""Conflict"""

    data: DeleteByOrgByRepoConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoNotAcceptableErrorData(BaseModel):
    error: models_deletebyorgbyrepoop.DeleteByOrgByRepoNotAcceptableError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: DeleteByOrgByRepoNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoNotFoundErrorData(BaseModel):
    error: models_deletebyorgbyrepoop.DeleteByOrgByRepoNotFoundError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoNotFoundError(MesaError):
    r"""Not found"""

    data: DeleteByOrgByRepoNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoForbiddenErrorData(BaseModel):
    error: models_deletebyorgbyrepoop.DeleteByOrgByRepoForbiddenError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoForbiddenError(MesaError):
    r"""Forbidden"""

    data: DeleteByOrgByRepoForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoUnauthorizedErrorData(BaseModel):
    error: models_deletebyorgbyrepoop.DeleteByOrgByRepoUnauthorizedError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: DeleteByOrgByRepoUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoBadRequestErrorData(BaseModel):
    error: models_deletebyorgbyrepoop.DeleteByOrgByRepoBadRequestError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoBadRequestError(MesaError):
    r"""Invalid request"""

    data: DeleteByOrgByRepoBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import getbyorgbyrepocommitsop as models_getbyorgbyrepocommitsop
from mesa_sdk.types import BaseModel
from typing import Optional


class GetByOrgByRepoCommitsInternalServerErrorData(BaseModel):
    error: models_getbyorgbyrepocommitsop.GetByOrgByRepoCommitsInternalServerErrorError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoCommitsInternalServerError(MesaError):
    r"""Internal error"""

    data: GetByOrgByRepoCommitsInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoCommitsInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoCommitsConflictErrorData(BaseModel):
    error: models_getbyorgbyrepocommitsop.GetByOrgByRepoCommitsConflictError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoCommitsConflictError(MesaError):
    r"""Conflict"""

    data: GetByOrgByRepoCommitsConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoCommitsConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoCommitsNotAcceptableErrorData(BaseModel):
    error: models_getbyorgbyrepocommitsop.GetByOrgByRepoCommitsNotAcceptableError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoCommitsNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: GetByOrgByRepoCommitsNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoCommitsNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoCommitsNotFoundErrorData(BaseModel):
    error: models_getbyorgbyrepocommitsop.GetByOrgByRepoCommitsNotFoundError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoCommitsNotFoundError(MesaError):
    r"""Not found"""

    data: GetByOrgByRepoCommitsNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoCommitsNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoCommitsForbiddenErrorData(BaseModel):
    error: models_getbyorgbyrepocommitsop.GetByOrgByRepoCommitsForbiddenError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoCommitsForbiddenError(MesaError):
    r"""Forbidden"""

    data: GetByOrgByRepoCommitsForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoCommitsForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoCommitsUnauthorizedErrorData(BaseModel):
    error: models_getbyorgbyrepocommitsop.GetByOrgByRepoCommitsUnauthorizedError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoCommitsUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: GetByOrgByRepoCommitsUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoCommitsUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoCommitsBadRequestErrorData(BaseModel):
    error: models_getbyorgbyrepocommitsop.GetByOrgByRepoCommitsBadRequestError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoCommitsBadRequestError(MesaError):
    r"""Invalid request"""

    data: GetByOrgByRepoCommitsBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoCommitsBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from mesa_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from mesa_sdk.utils import (
    FieldMetadata,
    PathParamMetadata,
    QueryParamMetadata,
    validate_const,
)
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Any, Awaitable, Callable, Dict, List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class GetByOrgReposRequestTypedDict(TypedDict):
    org: str
    cursor: NotRequired[str]
    limit: NotRequired[int]


class GetByOrgReposRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    cursor: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None

    limit: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["cursor", "limit"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgReposInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgReposInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgReposConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgReposConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgReposNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgReposNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgReposNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgReposNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgReposForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgReposForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgReposUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgReposUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgReposBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgReposBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


GetByOrgReposResolutionStrategy = Literal["none",]
r"""Conflict resolution strategy. \"none\" means sync will fail on conflicts."""


class GetByOrgReposAutosyncTypedDict(TypedDict):
    period: float
    r"""Polling period in seconds"""
    resolution_strategy: GetByOrgReposResolutionStrategy
    r"""Conflict resolution strategy. \"none\" means sync will fail on conflicts."""
    type: Literal["poll"]


class GetByOrgReposAutosync(BaseModel):
    period: float
    r"""Polling period in seconds"""

    resolution_strategy: GetByOrgReposResolutionStrategy
    r"""Conflict resolution strategy. \"none\" means sync will fail on conflicts."""

    type: Annotated[
        Annotated[Literal["poll"], AfterValidator(validate_const("poll"))],
        pydantic.Field(alias="type"),
    ] = "poll"


class GetByOrgReposUpstreamTypedDict(TypedDict):
    uri: str
    r"""URL of the upstream repository"""
    autosync: Nullable[GetByOrgReposAutosyncTypedDict]
    r"""Automatic sync configuration, if enabled"""
    last_sync_attempt: Nullable[datetime]
    r"""Timestamp of the last sync attempt"""
    last_sync_success: Nullable[datetime]
    r"""Timestamp of the last successful sync"""
    last_sync_error: Nullable[str]
    r"""Error message from the last failed sync attempt"""


class GetByOrgReposUpstream(BaseModel):
    uri: str
    r"""URL of the upstream repository"""

    autosync: Nullable[GetByOrgReposAutosync]
    r"""Automatic sync configuration, if enabled"""

    last_sync_attempt: Nullable[datetime]
    r"""Timestamp of the last sync attempt"""

    last_sync_success: Nullable[datetime]
    r"""Timestamp of the last successful sync"""

    last_sync_error: Nullable[str]
    r"""Error message from the last failed sync attempt"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class RepoTypedDict(TypedDict):
    id: str
    org: str
    name: str
    default_branch: str
    size_bytes: float
    last_push_at: Nullable[str]
    created_at: str
    upstream: Nullable[GetByOrgReposUpstreamTypedDict]
    r"""Optionally add an upstream repository. You can configure automatic syncing from the upstream repository."""


class Repo(BaseModel):
    id: str

    org: str

    name: str

    default_branch: str

    size_bytes: float

    last_push_at: Nullable[str]

    created_at: str

    upstream: Nullable[GetByOrgReposUpstream]
    r"""Optionally add an upstream repository. You can configure automatic syncing from the upstream repository."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetByOrgReposResponseBodyTypedDict(TypedDict):
    r"""Repository list"""

    next_cursor: Nullable[str]
    has_more: bool
    repos: List[RepoTypedDict]


class GetByOrgReposResponseBody(BaseModel):
    r"""Repository list"""

    next_cursor: Nullable[str]

    has_more: bool

    repos: List[Repo]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetByOrgReposResponseTypedDict(TypedDict):
    result: GetByOrgReposResponseBodyTypedDict


class GetByOrgReposResponse(BaseModel):
    next: Union[
        Callable[[], Optional[GetByOrgReposResponse]],
        Callable[[], Awaitable[Optional[GetByOrgReposResponse]]],
    ]

    result: GetByOrgReposResponseBody



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mesa_sdk.types import BaseModel, UNSET_SENTINEL
from mesa_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from pydantic import model_serializer
from typing import Any, Dict, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetByOrgByRepoCommitsByShaRequestTypedDict(TypedDict):
    org: str
    repo: str
    sha: str


class GetByOrgByRepoCommitsByShaRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    repo: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    sha: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class GetByOrgByRepoCommitsByShaInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoCommitsByShaInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsByShaConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoCommitsByShaConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsByShaNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoCommitsByShaNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsByShaNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoCommitsByShaNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsByShaForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoCommitsByShaForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsByShaUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoCommitsByShaUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsByShaBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoCommitsByShaBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsByShaAuthorTypedDict(TypedDict):
    name: str
    email: str
    date_: NotRequired[str]


class GetByOrgByRepoCommitsByShaAuthor(BaseModel):
    name: str

    email: str

    date_: Annotated[Optional[str], pydantic.Field(alias="date")] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["date"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsByShaCommitterTypedDict(TypedDict):
    name: str
    email: str
    date_: NotRequired[str]


class GetByOrgByRepoCommitsByShaCommitter(BaseModel):
    name: str

    email: str

    date_: Annotated[Optional[str], pydantic.Field(alias="date")] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["date"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoCommitsByShaResponseTypedDict(TypedDict):
    r"""Commit"""

    sha: str
    message: str
    author: GetByOrgByRepoCommitsByShaAuthorTypedDict
    committer: GetByOrgByRepoCommitsByShaCommitterTypedDict


class GetByOrgByRepoCommitsByShaResponse(BaseModel):
    r"""Commit"""

    sha: str

    message: str

    author: GetByOrgByRepoCommitsByShaAuthor

    committer: GetByOrgByRepoCommitsByShaCommitter
